@@ -385,7 +385,13 @@ class skl_graph_t(ntkx.MultiGraph):
 
     def AsNetworkX(self) -> ntkx.MultiGraph:
         """"""
-        return ntkx.MultiGraph(incoming_graph_data=self)
+        output = ntkx.MultiGraph(incoming_graph_data=self)
+
+        for source, target, details in self.edges.data("details"):
+            uid = details.uid
+            output.edges[source, target, uid]["uid"] = uid
+
+        return output
 
     def RebuiltSkeletonMap(self, /, *, with_width: bool = False) -> array_t:
         """"""
