@@ -40,12 +40,25 @@ from skl_graph.type.node import array_t, branch_node_t, end_node_t, node_t
 from skl_graph.type.plot import label_style_t, node_style_t, node_styles_h
 
 
+# TODO: clarify the distinction between this and dict[str, tuple[int, ...]] (used in plot.graph)
+positions_as_dict_h = dict[str, tuple[array_t, ...]]
+
+
+def PositionsForPlotFromDetails(
+    details: Iterable[tuple[str, node_t]], TransformedY: Callable[[array_t], array_t], /
+) -> positions_as_dict_h:
+    """"""
+    TransformedPosition = lambda _psn: (_psn[1], TransformedY(_psn[0]), *_psn[2:])
+
+    return dict((_uid, TransformedPosition(_dtl.position)) for _uid, _dtl in details)
+
+
 def PlotEndNodes(
     nodes: Iterable[tuple[str, node_t]],
-    transformation: Callable[[array_t], array_t],
+    TransformedY: Callable[[array_t], array_t],
     axes: axes_t,
     node_style: node_style_t,
-    /
+    /,
 ) -> None:
     """
     nodes: all the nodes of the graph, so that filtering is needed here
@@ -61,14 +74,14 @@ def PlotEndNodes(
     if positions.shape[1] == 2:
         axes.plot(
             positions[:, 1],
-            transformation(positions[:, 0]),
+            TransformedY(positions[:, 0]),
             plot_style,
             markersize=node_style.size,
         )
     else:
         axes.plot3D(
             positions[:, 1],
-            transformation(positions[:, 0]),
+            TransformedY(positions[:, 0]),
             positions[:, 2],
             plot_style,
             markersize=node_style.size,
@@ -82,7 +95,7 @@ def PlotEndNodes(
 def Plot2DBranchNodes(
     nodes: Iterable[tuple[str, node_t]],
     degrees: dict[str, int],
-    transformation: Callable[[array_t], array_t],
+    TransformedY: Callable[[array_t], array_t],
     axes: axes_t,
     node_styles: node_styles_h,
 ) -> None:
@@ -95,7 +108,7 @@ def Plot2DBranchNodes(
             node_style = node_styles.get(degrees[uid], default_style)
 
             coords_0 = details.sites[1]
-            coords_1 = transformation(details.sites[0])
+            coords_1 = TransformedY(details.sites[0])
             if coords_0.size > 3:
                 try:
                     hull = sptl.ConvexHull(nmpy.transpose((coords_0, coords_1)))
@@ -140,7 +153,7 @@ def Plot2DBranchNodes(
 def Plot3DBranchNodes(
     nodes: Iterable[tuple[str, node_t]],
     degrees: dict[str, int],
-    transformation: Callable[[array_t], array_t],
+    TransformedY: Callable[[array_t], array_t],
     axes: axes_t,
     node_styles: node_styles_h,
 ) -> None:
@@ -153,7 +166,7 @@ def Plot3DBranchNodes(
             node_style = node_styles.get(degrees[uid], default_style)
 
             coords_0 = details.sites[1]
-            coords_1 = transformation(details.sites[0])
+            coords_1 = TransformedY(details.sites[0])
             coords_2 = details.sites[2]
             if coords_0.size > 3:
                 # Could be > 4 with an explicit handling of ==3, but simpler this way
@@ -206,7 +219,7 @@ def Plot3DBranchNodes(
 
 def Plot3DNodeLabels(
     nodes: Iterable[str],
-    positions_as_dict: dict[str, tuple[int, ...]],
+    positions_as_dict: positions_as_dict_h,
     axes: axes_t,
     style: label_style_t,
 ) -> None:
